@@ -39,6 +39,7 @@ class PageController(Controller):
 
 class Page(object):
 
+    BANNER = None
     FOOTER = None
 
     def __init__(self, reddit, term, config, oauth):
@@ -162,6 +163,8 @@ class Page(object):
         data = self.get_selected_item()
         if 'likes' not in data:
             self.term.flash()
+        elif getattr(data['object'], 'archived'):
+            self.term.show_notification("Voting disabled for archived post", style='Error')
         elif data['likes']:
             with self.term.loader('Clearing vote'):
                 data['object'].clear_vote()
@@ -179,6 +182,8 @@ class Page(object):
         data = self.get_selected_item()
         if 'likes' not in data:
             self.term.flash()
+        elif getattr(data['object'], 'archived'):
+            self.term.show_notification("Voting disabled for archived post", style='Error')
         elif data['likes'] or data['likes'] is None:
             with self.term.loader('Voting'):
                 data['object'].downvote()
@@ -259,19 +264,19 @@ class Page(object):
             return
 
         if data['type'] == 'Submission':
-            subreddit = self.reddit.get_subreddit(self.content.name)
             content = data['text']
             info = docs.SUBMISSION_EDIT_FILE.format(
-                content=content, name=subreddit)
+                content=content, id=data['object'].id)
         elif data['type'] == 'Comment':
             content = data['body']
-            info = docs.COMMENT_EDIT_FILE.format(content=content)
+            info = docs.COMMENT_EDIT_FILE.format(
+                content=content, id=data['object'].id)
         else:
             self.term.flash()
             return
 
         with self.term.open_editor(info) as text:
-            if text == content:
+            if not text or text == content:
                 self.term.show_notification('Canceled')
                 return
 
@@ -299,6 +304,39 @@ class Page(object):
             message = 'New Messages' if inbox > 0 else 'No New Messages'
             self.term.show_notification(message)
 
+    def prompt_and_select_link(self):
+        """
+        Prompt the user to select a link from a list to open.
+
+        Return the link that was selected, or ``None`` if no link was selected.
+        """
+        data = self.get_selected_item()
+        url_full = data.get('url_full')
+        permalink = data.get('permalink')
+
+        if url_full and url_full != permalink:
+            # The item is a link-only submission that won't contain text
+            link = url_full
+        else:
+            html = data.get('html')
+            if html:
+                extracted_links = self.content.extract_links(html)
+                if not extracted_links:
+                    # Only one selection to choose from, so just pick it
+                    link = permalink
+                else:
+                    # Let the user decide which link to open
+                    links = []
+                    if permalink:
+                        links += [{'text': 'Permalink', 'href': permalink}]
+                    links += extracted_links
+                    link = self.term.prompt_user_to_select_link(links)
+            else:
+                # Some items like hidden comments don't have any HTML to parse
+                link = permalink
+
+        return link
+
     @PageController.register(Command('COPY_PERMALINK'))
     def copy_permalink(self):
         """
@@ -324,11 +362,9 @@ class Page(object):
     @PageController.register(Command('COPY_URL'))
     def copy_url(self):
         """
-        Copies submission url to OS clipboard
+        Copies link to OS clipboard
         """
-
-        data = self.get_selected_item()
-        url = data.get('url_full')
+        url = self.prompt_and_select_link()
         if url is None:
             self.term.flash()
             return
@@ -341,7 +377,7 @@ class Page(object):
                 'Failed to copy url: {0}'.format(e))
         else:
             self.term.show_notification(
-                'Copied url to clipboard', timeout=1)
+                ['Copied to clipboard:', url], timeout=1)
 
     def clear_input_queue(self):
         """
@@ -353,7 +389,9 @@ class Page(object):
                 continue
 
     def draw(self):
-
+        """
+        Clear the terminal screen and redraw all of the sub-windows
+        """
         n_rows, n_cols = self.term.stdscr.getmaxyx()
         if n_rows < self.term.MIN_HEIGHT or n_cols < self.term.MIN_WIDTH:
             # TODO: Will crash when you try to navigate if the terminal is too
@@ -369,7 +407,9 @@ class Page(object):
         self.term.stdscr.refresh()
 
     def _draw_header(self):
-
+        """
+        Draw the title bar at the top of the screen
+        """
         n_rows, n_cols = self.term.stdscr.getmaxyx()
 
         # Note: 2 argument form of derwin breaks PDcurses on Windows 7!
@@ -380,8 +420,26 @@ class Page(object):
 
         sub_name = self.content.name
         sub_name = sub_name.replace('/r/front', 'Front Page')
-        sub_name = sub_name.replace('/u/me', 'My Submissions')
-        sub_name = sub_name.replace('/u/saved', 'My Saved Submissions')
+
+        parts = sub_name.split('/')
+        if len(parts) == 1:
+            pass
+        elif '/m/' in sub_name:
+            _, _, user, _, multi = parts
+            sub_name = '{} Curated by {}'.format(multi, user)
+        elif parts[1] == 'u':
+            noun = 'My' if parts[2] == 'me' else parts[2] + "'s"
+            user_room = parts[3] if len(parts) == 4 else 'overview'
+            title_lookup = {
+                'overview': 'Overview',
+                'submitted': 'Submissions',
+                'comments': 'Comments',
+                'saved': 'Saved Content',
+                'hidden': 'Hidden Content',
+                'upvoted': 'Upvoted Content',
+                'downvoted': 'Downvoted Content'
+            }
+            sub_name = "{} {}".format(noun, title_lookup[user_room])
 
         query = self.content.query
         if query:
@@ -391,8 +449,11 @@ class Page(object):
         # Set the terminal title
         if len(sub_name) > 50:
             title = sub_name.strip('/')
-            title = title.rsplit('/', 1)[1]
             title = title.replace('_', ' ')
+            try:
+                title = title.rsplit('/', 1)[1]
+            except IndexError:
+                pass
         else:
             title = sub_name
 
@@ -427,13 +488,15 @@ class Page(object):
         self._row += 1
 
     def _draw_banner(self):
-
+        """
+        Draw the banner with sorting options at the top of the page
+        """
         n_rows, n_cols = self.term.stdscr.getmaxyx()
         window = self.term.stdscr.derwin(1, n_cols, self._row, 0)
         window.erase()
         window.bkgd(str(' '), self.term.attr('OrderBar'))
 
-        banner = docs.BANNER_SEARCH if self.content.query else docs.BANNER
+        banner = docs.BANNER_SEARCH if self.content.query else self.BANNER
         items = banner.strip().split(' ')
 
         distance = (n_cols - sum(len(t) for t in items) - 1) / (len(items) - 1)
@@ -452,7 +515,6 @@ class Page(object):
         """
         Loop through submissions and fill up the content page.
         """
-
         n_rows, n_cols = self.term.stdscr.getmaxyx()
         window = self.term.stdscr.derwin(n_rows - self._row - 1, n_cols, self._row, 0)
         window.erase()
@@ -525,7 +587,9 @@ class Page(object):
         self._row += win_n_rows
 
     def _draw_footer(self):
-
+        """
+        Draw the key binds help bar at the bottom of the screen
+        """
         n_rows, n_cols = self.term.stdscr.getmaxyx()
         window = self.term.stdscr.derwin(1, n_cols, self._row, 0)
         window.erase()
@@ -548,7 +612,6 @@ class Page(object):
             self.term.flash()
 
     def _prompt_period(self, order):
-
         choices = {
             '\n': order,
             '1': '{0}-hour'.format(order),
