@@ -17,6 +17,7 @@ class SubmissionController(PageController):
 
 class SubmissionPage(Page):
 
+    BANNER = docs.BANNER_SUBMISSION
     FOOTER = docs.FOOTER_SUBMISSION
 
     def __init__(self, reddit, term, config, oauth, url=None, submission=None):
@@ -137,15 +138,21 @@ class SubmissionPage(Page):
     @SubmissionController.register(Command('SUBMISSION_OPEN_IN_BROWSER'))
     def open_link(self):
         """
-        Open the selected item with the web browser
-        """
+        Open the link contained in the selected item.
 
+        If there is more than one link contained in the item, prompt the user
+        to choose which link to open.
+        """
         data = self.get_selected_item()
         if data['type'] == 'Submission':
-            self.term.open_link(data['url_full'])
-            self.config.history.add(data['url_full'])
-        elif data['type'] == 'Comment' and data['permalink']:
-            self.term.open_browser(data['permalink'])
+            link = self.prompt_and_select_link()
+            if link:
+                self.config.history.add(link)
+                self.term.open_link(link)
+        elif data['type'] == 'Comment':
+            link = self.prompt_and_select_link()
+            if link:
+                self.term.open_link(link)
         else:
             self.term.flash()
 
@@ -157,6 +164,9 @@ class SubmissionPage(Page):
 
         n_rows, n_cols = self.term.stdscr.getmaxyx()
 
+        if self.config['max_pager_cols'] is not None:
+            n_cols = min(n_cols, self.config['max_pager_cols'])
+
         data = self.get_selected_item()
         if data['type'] == 'Submission':
             text = '\n\n'.join((data['permalink'], data['text']))
@@ -191,7 +201,7 @@ class SubmissionPage(Page):
 
         # Construct the text that will be displayed in the editor file.
         # The post body will be commented out and added for reference
-        lines = ['#  |' + line for line in body.split('\n')]
+        lines = ['  |' + line for line in body.split('\n')]
         content = '\n'.join(lines)
         comment_info = docs.COMMENT_FILE.format(
             author=data['author'],
@@ -339,12 +349,15 @@ class SubmissionPage(Page):
 
             attr = self.term.attr('Created')
             self.term.add_space(win)
-            self.term.add_line(win, '{created}'.format(**data), attr=attr)
+            self.term.add_line(win, '{created}{edited}'.format(**data),
+                               attr=attr)
 
             if data['gold']:
                 attr = self.term.attr('Gold')
                 self.term.add_space(win)
-                self.term.add_line(win, self.term.guilded, attr=attr)
+                count = 'x{}'.format(data['gold']) if data['gold'] > 1 else ''
+                text = self.term.gilded + count
+                self.term.add_line(win, text, attr=attr)
 
             if data['stickied']:
                 attr = self.term.attr('Stickied')
@@ -408,7 +421,8 @@ class SubmissionPage(Page):
 
         attr = self.term.attr('Created')
         self.term.add_space(win)
-        self.term.add_line(win, '{created_long}'.format(**data), attr=attr)
+        self.term.add_line(win, '{created_long}{edited_long}'.format(**data),
+                           attr=attr)
 
         row = len(data['split_title']) + 2
         if data['url_full'] in self.config.history:
@@ -445,7 +459,9 @@ class SubmissionPage(Page):
         if data['gold']:
             attr = self.term.attr('Gold')
             self.term.add_space(win)
-            self.term.add_line(win, self.term.guilded, attr=attr)
+            count = 'x{}'.format(data['gold']) if data['gold'] > 1 else ''
+            text = self.term.gilded + count
+            self.term.add_line(win, text, attr=attr)
 
         if data['nsfw']:
             attr = self.term.attr('NSFW')
