@@ -19,6 +19,7 @@ class SubredditController(PageController):
 
 class SubredditPage(Page):
 
+    BANNER = docs.BANNER_SUBREDDIT
     FOOTER = docs.FOOTER_SUBREDDIT
 
     def __init__(self, reddit, term, config, oauth, name):
@@ -100,6 +101,13 @@ class SubredditPage(Page):
             else:
                 self.refresh_content(order=order)
 
+    @SubredditController.register(Command('SORT_GILDED'))
+    def sort_content_gilded(self):
+        if self.content.query:
+            self.term.flash()
+        else:
+            self.refresh_content(order='gilded')
+
     @SubredditController.register(Command('SUBREDDIT_SEARCH'))
     def search_subreddit(self, name=None):
         """
@@ -345,7 +353,8 @@ class SubredditPage(Page):
             self.term.add_space(win)
 
             attr = self.term.attr('Created')
-            self.term.add_line(win, '{created}'.format(**data), attr=attr)
+            self.term.add_line(win, '{created}{edited}'.format(**data),
+                               attr=attr)
 
             if data['comments'] is not None:
                 attr = self.term.attr('Separator')
@@ -374,7 +383,9 @@ class SubredditPage(Page):
             if data['gold']:
                 attr = self.term.attr('Gold')
                 self.term.add_space(win)
-                self.term.add_line(win, self.term.guilded, attr=attr)
+                count = 'x{}'.format(data['gold']) if data['gold'] > 1 else ''
+                text = self.term.gilded + count
+                self.term.add_line(win, text, attr=attr)
 
             if data['nsfw']:
                 attr = self.term.attr('NSFW')
