@@ -2,6 +2,7 @@
 from __future__ import unicode_literals
 
 import os
+import re
 import sys
 import time
 import shlex
@@ -21,6 +22,7 @@ import six
 from kitchen.text.display import textual_width_chop
 
 from . import exceptions, mime_parsers, content
+from .docs import TOKEN
 from .theme import Theme, ThemeList
 from .objects import LoadScreen
 
@@ -80,7 +82,7 @@ class Terminal(object):
         return 'o' if self.config['ascii'] else '•'
 
     @property
-    def guilded(self):
+    def gilded(self):
         return '*' if self.config['ascii'] else '✪'
 
     @property
@@ -352,6 +354,74 @@ class Terminal(object):
 
         return ch
 
+    def prompt_user_to_select_link(self, links):
+        """
+        Prompt the user to select a link from a list to open.
+
+        Return the link that was selected, or ``None`` if no link was selected.
+        """
+        link_pages = self.get_link_pages(links)
+        n = 0
+        while n in range(len(link_pages)):
+            link_page = link_pages[n]
+            text = 'Select a link to open (page {} of {}):\n\n'
+            text = text.format(n+1, len(link_pages))
+            text += self.get_link_page_text(link_page)
+            if link_page is not link_pages[-1]:
+                text += '[j] next page...'
+            if link_page is not link_pages[0]:
+                if link_page is not link_pages[-1]:
+                    text += '\n'
+                text += '[k] ...previous page'
+
+            try:
+                choice = chr(self.show_notification(text))
+                try:
+                    choice = int(choice)
+                except ValueError:
+                    pass
+            except ValueError:
+                return None
+            if choice == 'j':
+                if link_page is not link_pages[-1]:
+                    n += 1
+                continue
+            elif choice == 'k':
+                if link_page is not link_pages[0]:
+                    n -= 1
+                continue
+            elif choice not in range(len(link_page)):
+                return None
+            return link_page[choice]['href']
+
+    @staticmethod
+    def get_link_pages(links):
+        """
+        Given a list of links, separate them into pages that can be displayed
+        to the user and navigated using the 1-9 and 0 number keys.
+        """
+        link_pages = []
+        i = 0
+        while i < len(links):
+            link_page = []
+            while i < len(links) and len(link_page) < 10:
+                link_page.append(links[i])
+                i += 1
+            link_pages.append(link_page)
+        return link_pages
+
+    @staticmethod
+    def get_link_page_text(link_page):
+        """
+        Construct the dialog box to display a list of links to the user.
+        """
+        text = ''
+        for i, link in enumerate(link_page):
+            capped_link_text = (link['text'] if len(link['text']) <= 20
+                                else link['text'][:19] + '…')
+            text += '[{}] [{}]({})\n'.format(i, capped_link_text, link['href'])
+        return text
+
     def open_link(self, url):
         """
         Open a media link using the definitions from the user's mailcap file.
@@ -560,12 +630,17 @@ class Terminal(object):
 
     def open_pager(self, data, wrap=None):
         """
-        View a long block of text using the system's default pager.
+        View a long block of text using an external pager / viewer.  The setting
+        of the RTV_PAGER variable will be used if set, otherwise the system's
+        default pager is chosen, finally defaulting to 'less' if both RTV_PAGER
+        and PAGER is unset in the calling environment.
 
         The data string will be piped directly to the pager.
         """
 
-        pager = os.getenv('PAGER') or 'less'
+        pager = os.getenv('RTV_PAGER')
+        if pager is None:
+                pager = os.getenv('PAGER') or 'less'
         command = shlex.split(pager)
 
         if wrap:
@@ -589,10 +664,11 @@ class Terminal(object):
         """
         Open a file for editing using the system's default editor.
 
-        After the file has been altered, the text will be read back and lines
-        starting with '#' will be stripped. If an error occurs inside of the
-        context manager, the file will be preserved. Otherwise, the file will
-        be deleted when the context manager closes.
+        After the file has been altered, the text will be read back and the
+        HTML comment tag <!--INSRUCTIONS --> will be stripped. If an error
+        occurs inside of the context manager, the file will be preserved so
+        users can recover their data. Otherwise, the file will be deleted when
+        the context manager closes.
 
         Params:
             data (str): If provided, text will be written to the file before
@@ -629,8 +705,8 @@ class Terminal(object):
             self.show_notification('Could not open file with %s' % editor)
 
         with codecs.open(filepath, 'r', 'utf-8') as fp:
-            text = ''.join(line for line in fp if not line.startswith('#'))
-            text = text.rstrip()
+            text = fp.read()
+            text = self.strip_instructions(text)
 
         try:
             yield text
@@ -824,6 +900,20 @@ class Terminal(object):
         out = '\n'.join(stack)
         return out
 
+    @staticmethod
+    def strip_instructions(text):
+        """
+        Remove instructional HTML comment tags inserted by RTV.
+
+        We used to use # to annotate comments, but it conflicted with the
+        header tag for markdown, which some people use to format their posts.
+        """
+        # Pattern can span multiple lines, allows dot to match newline chars
+        flags = re.MULTILINE | re.DOTALL
+        pattern = '<!--{token}(.*?){token}-->'.format(token=TOKEN)
+        text = re.sub(pattern, '', text, flags=flags)
+        return re.sub('\A[\s\n]*\n', '', text, flags=flags).rstrip()
+
     def clear_screen(self):
         """
         In the beginning this always called touchwin(). However, a bug
