@@ -30,11 +30,7 @@ def test_subreddit_page_construct(reddit, terminal, config, oauth):
     window.addstr.assert_any_call(0, 0, title)
 
     # Banner
-    menu = ('[1]hot         '
-            '[2]top         '
-            '[3]rising         '
-            '[4]new         '
-            '[5]controversial').encode('utf-8')
+    menu = '[1]hot     [2]top     [3]rising     [4]new     [5]controversial     [6]gilded'.encode('utf-8')
     window.addstr.assert_any_call(0, 0, menu)
 
     # Submission
@@ -194,6 +190,9 @@ def test_subreddit_prompt_submission_invalid(subreddit_page, terminal):
 
 def test_subreddit_order(subreddit_page):
 
+    # /r/python doesn't always have rising submissions, so use a larger sub
+    subreddit_page.refresh_content(name='all')
+
     subreddit_page.content.query = ''
     subreddit_page.controller.trigger('1')
     assert subreddit_page.content.order == 'hot'
@@ -201,6 +200,8 @@ def test_subreddit_order(subreddit_page):
     assert subreddit_page.content.order == 'rising'
     subreddit_page.controller.trigger('4')
     assert subreddit_page.content.order == 'new'
+    subreddit_page.controller.trigger('6')
+    assert subreddit_page.content.order == 'gilded'
 
     subreddit_page.content.query = 'search text'
     subreddit_page.controller.trigger('1')
@@ -208,6 +209,11 @@ def test_subreddit_order(subreddit_page):
     subreddit_page.controller.trigger('4')
     assert subreddit_page.content.order == 'new'
 
+    # Shouldn't be able to sort queries by gilded
+    subreddit_page.controller.trigger('6')
+    assert curses.flash.called
+    assert subreddit_page.content.order == 'new'
+
 
 def test_subreddit_order_top(subreddit_page, terminal):
 
@@ -416,17 +422,35 @@ def test_subreddit_open_multireddits(subreddit_page, refresh_token):
         assert loop.called
 
 
-def test_subreddit_saved(subreddit_page, refresh_token):
+def test_subreddit_private_user_pages(subreddit_page, refresh_token):
 
     # Log in
     subreddit_page.config.refresh_token = refresh_token
     subreddit_page.oauth.authorize()
 
-    subreddit_page.refresh_content(name='/u/saved')
+    subreddit_page.refresh_content(name='/u/me/saved')
+    subreddit_page.draw()
+
+    subreddit_page.refresh_content(name='/u/me/hidden')
+    subreddit_page.draw()
+
+    subreddit_page.refresh_content(name='/u/me/upvoted')
+    subreddit_page.draw()
+
+    subreddit_page.refresh_content(name='/u/me/downvoted')
+    subreddit_page.draw()
+
+    subreddit_page.refresh_content(name='/u/me/overview')
+    subreddit_page.draw()
+
+    subreddit_page.refresh_content(name='/u/me/submitted')
+    subreddit_page.draw()
+
+    subreddit_page.refresh_content(name='/u/me/comments')
     subreddit_page.draw()
 
 
-def test_subreddit_user_overview(subreddit_page, refresh_token):
+def test_subreddit_user_pages(subreddit_page, refresh_token):
 
     # Log in
     subreddit_page.config.refresh_token = refresh_token
@@ -435,9 +459,20 @@ def test_subreddit_user_overview(subreddit_page, refresh_token):
     # Pick a user that has a lot of recent comments, so we can make sure that
     # SavedComment objects have all of the properties necessary to be drawn
     # on the submission page.
+
+    # Should default to the overview page
     subreddit_page.refresh_content(name='/u/spez')
     subreddit_page.draw()
 
+    subreddit_page.refresh_content(name='/u/spez/overview')
+    subreddit_page.draw()
+
+    subreddit_page.refresh_content(name='/u/spez/submitted')
+    subreddit_page.draw()
+
+    subreddit_page.refresh_content(name='/u/spez/comments')
+    subreddit_page.draw()
+
 
 def test_subreddit_draw_header(subreddit_page, refresh_token, terminal):
 
@@ -459,23 +494,36 @@ def test_subreddit_draw_header(subreddit_page, refresh_token, terminal):
     # /u/me alias should be renamed in the header
     subreddit_page.refresh_content(name='/u/me')
     subreddit_page.draw()
-    text = 'My Submissions'.encode('utf-8')
+    text = 'My Overview'.encode('utf-8')
     terminal.stdscr.subwin.addstr.assert_any_call(0, 0, text)
 
     subreddit_page.refresh_content(name='/u/me/new')
     subreddit_page.draw()
-    text = 'My Submissions'.encode('utf-8')
+    text = 'My Overview'.encode('utf-8')
     terminal.stdscr.subwin.addstr.assert_any_call(0, 0, text)
 
     # /u/saved alias should be renamed in the header
-    subreddit_page.refresh_content(name='/u/saved')
+    subreddit_page.refresh_content(name='/u/me/saved')
     subreddit_page.draw()
-    text = 'My Saved Submissions'.encode('utf-8')
+    text = 'My Saved Content'.encode('utf-8')
     terminal.stdscr.subwin.addstr.assert_any_call(0, 0, text)
 
-    subreddit_page.refresh_content(name='/u/saved/new')
+    # /u/upvoted alias should be renamed in the header
+    subreddit_page.refresh_content(name='/u/me/upvoted')
     subreddit_page.draw()
-    text = 'My Saved Submissions'.encode('utf-8')
+    text = 'My Upvoted Content'.encode('utf-8')
+    terminal.stdscr.subwin.addstr.assert_any_call(0, 0, text)
+
+    # /u/downvoted alias should be renamed in the header
+    subreddit_page.refresh_content(name='/u/me/downvoted')
+    subreddit_page.draw()
+    text = 'My Downvoted Content'.encode('utf-8')
+    terminal.stdscr.subwin.addstr.assert_any_call(0, 0, text)
+
+    # /u/hidden alias should be renamed in the header
+    subreddit_page.refresh_content(name='/u/me/hidden')
+    subreddit_page.draw()
+    text = 'My Hidden Content'.encode('utf-8')
     terminal.stdscr.subwin.addstr.assert_any_call(0, 0, text)
 
 
@@ -518,4 +566,4 @@ def test_subreddit_hide_submission(subreddit_page, refresh_token):
 
     # Make sure that the status was actually updated on the server side
     data['object'].refresh()
-    assert data['object'].hidden is False
\ No newline at end of file
+    assert data['object'].hidden is False
